@@ -1,25 +1,16 @@
 from __future__ import absolute_import, unicode_literals
+
 import logging
-try:
-    from pkgutil import extend_path
-    __path__ = extend_path(__path__, __name__)
-except ImportError:
-    from pkg_resources import declare_namespace
-    declare_namespace(__name__)
 
-from wechatpy.parser import parse_message  # NOQA
-from wechatpy.replies import create_reply  # NOQA
 from wechatpy.client import WeChatClient  # NOQA
-from wechatpy.exceptions import WeChatException  # NOQA
-from wechatpy.exceptions import WeChatClientException  # NOQA
+from wechatpy.component import ComponentOAuth, WeChatComponent  # NOQA
+from wechatpy.exceptions import WeChatClientException, WeChatException, WeChatOAuthException, WeChatPayException  # NOQA
 from wechatpy.oauth import WeChatOAuth  # NOQA
-from wechatpy.exceptions import WeChatOAuthException  # NOQA
+from wechatpy.parser import parse_message  # NOQA
 from wechatpy.pay import WeChatPay  # NOQA
-from wechatpy.exceptions import WeChatPayException  # NOQA
-from wechatpy.component import WeChatComponent  # NOQA
+from wechatpy.replies import create_reply  # NOQA
 
-
-__version__ = '1.3.1'
+__version__ = '1.8.7'
 __author__ = 'messense'
 
 # Set default logging handler to avoid "No handler found" warnings.
